@@ -1,6 +1,9 @@
 from unit.api.base_resource import BaseResource
 from unit.models.webhook import *
 from unit.models.codecs import DtoDecoder
+import hmac
+from hashlib import sha1
+import base64
 
 
 class WebhookResource(BaseResource):
@@ -58,3 +61,11 @@ class WebhookResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
+    def verify(self, signature: str, secret: str, payload):
+        mac = hmac.new(
+            secret.encode(),
+            msg=json.dumps(payload, separators=(',', ':')).encode(),
+            digestmod=sha1,
+        )
+        res = base64.encodebytes(mac.digest()).decode().rstrip('\n')
+        return res == signature
