@@ -15,6 +15,13 @@ from unit.models.event import *
 from unit.models.counterparty import CounterpartyDTO
 from unit.models.webhook import WebhookDTO
 from unit.models.institution import InstitutionDTO
+from unit.models.statement import StatementDTO
+from unit.models.atm_location import AtmLocationDTO
+from unit.models.bill_pay import BillerDTO
+from unit.models.api_token import APITokenDTO
+from unit.models.authorization import AuthorizationDTO
+from unit.models.authorization_request import PurchaseAuthorizationRequestDTO
+from unit.models.account_end_of_day import AccountEndOfDayDTO
 
 mappings = {
         "individualApplication": lambda _id, _type, attributes, relationships:
@@ -110,6 +117,12 @@ mappings = {
         "wirePayment": lambda _id, _type, attributes, relationships:
         WirePaymentDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "accountStatementDTO": lambda _id, _type, attributes, relationships:
+        StatementDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "sandboxAccountStatement": lambda _id, _type, attributes, relationships:
+        StatementDTO.from_json_api(_id, _type, attributes, relationships),
+
         "customerBearerToken": lambda _id, _type, attributes, relationships:
         CustomerTokenDTO.from_json_api(_id, _type, attributes, relationships),
 
@@ -193,16 +206,35 @@ mappings = {
 
         "customer.created": lambda _id, _type, attributes, relationships:
         CustomerCreatedEvent.from_json_api(_id, _type, attributes, relationships),
+
         "webhook": lambda _id, _type, attributes, relationships:
         WebhookDTO.from_json_api(_id, _type, attributes, relationships),
 
         "institution": lambda _id, _type, attributes, relationships:
         InstitutionDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "atmLocation": lambda _id, _type, attributes, relationships:
+        AtmLocationDTO.from_json_api(_type, attributes),
+
+        "biller": lambda _id, _type, attributes, relationships:
+        BillerDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "apiToken": lambda _id, _type, attributes, relationships:
+        APITokenDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "authorization": lambda _id, _type, attributes, relationships:
+        AuthorizationDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "purchaseAuthorizationRequest": lambda _id, _type, attributes, relationships:
+        PurchaseAuthorizationRequestDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "accountEndOfDay": lambda _id, _type, attributes, relationships:
+        AccountEndOfDayDTO.from_json_api(_id, _type, attributes, relationships),
+
     }
 
 
-def split_json_api_single_response(payload: dict):
+def split_json_api_single_response(payload: Dict):
     _id, _type, attributes = payload.get("id"), payload["type"], payload["attributes"]
     relationships = None
 
